UniformBlock
============

.. py:module:: moderngl
.. py:currentmodule:: moderngl

.. autoclass:: moderngl.UniformBlock

.. autoattribute:: UniformBlock.binding
.. autoattribute:: UniformBlock.name
.. autoattribute:: UniformBlock.index
.. autoattribute:: UniformBlock.size

.. toctree::
    :maxdepth: 2
